@@ -1,16 +1,16 @@
 #!/usr/bin/env bash
 
 mp_mkdir $TARNAME
-mp_source configure.ac $TARNAME "$PACKAGE" $BUGREPORT
+mp_source configure.ac $TARNAME "$PACKAGE" $BUGREPORT "$DEPENDENCIES"
 mp_source Makefile.am $TARNAME
 mp_source AUTHORS $TARNAME "$AUTHOR" $BUGREPORT
 mp_source ChangeLog $TARNAME "$AUTHOR" $BUGREPORT
 mp_source README $TARNAME "$PACKAGE" "$DESCRIPTION"
 mp_source NEWS $TARNAME
-mp_source_as ${TARNAME#lib}.pc.in lib.pc.in $TARNAME "$PACKAGE" "$DESCRIPTION"
+mp_source_as ${TARNAME#lib}.pc.in lib.pc.in $TARNAME "$PACKAGE" "$DESCRIPTION" "$DEPENDENCIES"
 
 mp_mkdir $TARNAME/src
-mp_source src/Makefile.am $TARNAME
+mp_source src/Makefile.am $TARNAME "$DEPENDENCIES"
 mp_cp src/lib.h $TARNAME
 mp_cp src/lib.c $TARNAME
 
