@@ -10,6 +10,17 @@ AM_PROG_CC_C_O
 AC_PROG_LIBTOOL
 
 # Checks for libraries.
+EOF
+if [[ -n $4 ]]
+then
+	cat >> $1/configure.ac <<-EOF
+	DEP_MODULES="$4"
+	PKG_CHECK_MODULES(DEPS, \$DEP_MODULES)
+	AC_SUBST(DEPS_CFLAGS)
+	AC_SUBST(DEPS_LIBS)
+	EOF
+fi
+cat >> $1/configure.ac <<EOF
 
 # Checks for header files.
 AC_STDC_HEADERS
