@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 
 mp_mkdir $TARNAME
-mp_source configure.ac $TARNAME "$PACKAGE" $BUGREPORT
+mp_source configure.ac $TARNAME "$PACKAGE" $BUGREPORT "$DEPENDENCIES"
 mp_cp Makefile.am $TARNAME
 mp_source AUTHORS $TARNAME "$AUTHOR" $BUGREPORT
 mp_source ChangeLog $TARNAME "$AUTHOR" $BUGREPORT
@@ -9,7 +9,7 @@ mp_source README $TARNAME "$PACKAGE" "$DESCRIPTION"
 mp_source NEWS $TARNAME
 
 mp_mkdir $TARNAME/src
-mp_source src/Makefile.am $TARNAME
+mp_source src/Makefile.am $TARNAME "$DEPENDENCIES"
 mp_cp src/main.c $TARNAME
 
 mp_exec "autoreconf -i" $TARNAME
