@@ -9,6 +9,6 @@ lib_LTLIBRARIES = ${LIBNAME}.la
 include_HEADERS = lib.h
 
 ${TRLIBNAME}_la_SOURCES = lib.h lib.c
-${TRLIBNAME}_la_CPPFLAGS = \$(DEPS_CFLAGS) -I.
+${TRLIBNAME}_la_CPPFLAGS = -I. \$(DEPS_CFLAGS)
 ${TRLIBNAME}_la_LIBADD = \$(DEPS_LIBS)
 EOF
