@@ -1,14 +1,14 @@
 #!/usr/bin/env bash
-DEP_MODULES="gobject-2.0 glib-2.0"
+DEPENDENCIES=$(mp_join "gobject-2.0 glib-2.0" "$DEPENDENCIES")
 
 mp_mkdir $TARNAME
-mp_source configure.ac $TARNAME "$PACKAGE" $BUGREPORT "$DEP_MODULES"
+mp_source configure.ac $TARNAME "$PACKAGE" $BUGREPORT "$DEPENDENCIES"
 mp_source Makefile.am $TARNAME
 mp_source AUTHORS $TARNAME "$AUTHOR" $BUGREPORT
 mp_source ChangeLog $TARNAME "$AUTHOR" $BUGREPORT
 mp_source README $TARNAME "$PACKAGE" "$DESCRIPTION"
 mp_source NEWS $TARNAME
-mp_source_as ${TARNAME#lib}.pc.in lib.pc.in $TARNAME "$PACKAGE" "$DESCRIPTION" "$DEP_MODULES"
+mp_source_as ${TARNAME#lib}.pc.in lib.pc.in $TARNAME "$PACKAGE" "$DESCRIPTION" "$DEPENDENCIES"
 
 mp_mkdir $TARNAME/src
 mp_source src/Makefile.am $TARNAME
