@@ -10,7 +10,7 @@ include_headers = lib.h g-hello-world.h
 
 ${TRLIBNAME}_la_SOURCES = g-hello-world.h g-hello-world-private.h g-hello-world.c g-hello-world.gob \\
 			  \$(BUILT_SOURCES)
-${TRLIBNAME}_la_CPPFLAGS = \$(DEPS_CFLAGS) -I.
+${TRLIBNAME}_la_CPPFLAGS = -I. \$(DEPS_CFLAGS)
 ${TRLIBNAME}_la_LIBADD = \$(DEPS_LIBS)
 
 BUILT_SOURCES = g-hello-world.gob.stamp
