@@ -1,8 +1,8 @@
 #!/usr/bin/env bash
-DEP_MODULES="gobject-2.0 glib-2.0"
+DEPENDENCIES=$(mp_join "gobject-2.0 glib-2.0" "$DEPENDENCIES")
 
 mp_mkdir $TARNAME
-mp_source configure.ac $TARNAME "$PACKAGE" $BUGREPORT "$DEP_MODULES"
+mp_source configure.ac $TARNAME "$PACKAGE" $BUGREPORT "$DEPENDENCIES"
 mp_cp Makefile.am $TARNAME
 mp_source AUTHORS $TARNAME "$AUTHOR" $BUGREPORT
 mp_source ChangeLog $TARNAME "$AUTHOR" $BUGREPORT
