@@ -20,12 +20,23 @@ MP_PROJECTDIR="$MP_DATADIR/$1/project"
 
 # mp functions
 
+function mp_join
+{
+	STRING="$1"
+	shift
+	while [[ $# -ne 0 ]]
+	do
+		STRING+=" $1"
+		shift
+	done
+	echo "$STRING"
+}
+
 function mp_mkdir
 {
 	if [[ -a $1 ]]
 	then
-		echo "Directory $(basename $1) exists."
-		exit 1
+		mp_error "$(basename $1): file exists"
 	else
 		printf "Creating directory $(basename "$1")..."
 			mkdir "$1"
@@ -37,8 +48,7 @@ function mp_source
 {
 	if [[ -a $1 ]]
 	then
-		echo "File $1 exists."
-		exit 1
+		mp_error "$1: file exists"
 	else
 		printf "Creating $1..."
 			source "$MP_PROJECTDIR/$1.sh" "$2" "$3" "$4" "$5"
@@ -50,8 +60,7 @@ function mp_source_as
 {
 	if [[ -a $1 ]]
 	then
-		echo "File $1 exists."
-		exit 1
+		mp_error "$1: file exists"
 	else
 		printf "Creating $1..."
 			source "$MP_PROJECTDIR/$2.sh" "$3" "$4" "$5" "$6"
@@ -61,10 +70,9 @@ function mp_source_as
 
 function mp_cp
 {
-	if [[ -a $1 ]]
+	if [[ -a $2/$1 ]]
 	then
-		echo "File $1 exists."
-		exit 1
+		mp_error "$1: file exists"
 	else
 		printf "Creating $1..."
 			cp "$MP_PROJECTDIR/$1" "$2/$1"
